@@ -5,19 +5,16 @@ from urllib.parse import unquote
 from concurrent.futures import as_completed
 from concurrent.futures.thread import ThreadPoolExecutor
 from pathlib import Path
-from io import BytesIO, StringIO
-from tempfile import NamedTemporaryFile
 from typing import Union, Generator
 
 import iouuid
 import requests
-from requests import Response
 from requests.adapters import HTTPAdapter
 
 from requests_futures.sessions import FuturesSession
 from lxml import html
 from urllib3 import Retry
-from pytube import YouTube, Stream
+from pytube import YouTube
 
 from pymoodle_jku.Classes.course import Course
 from pymoodle_jku.Classes.course_data import UrlType, Url, CourseData
